@@ -3,7 +3,7 @@ from pbu.logger import Logger
 from pbu.time_series import TimeSeries
 from pbu.paging import PagingInformation
 from pbu.basic_monitor import BasicMonitor, JobStatus
-from pbu.default_options import default_options, default_value, list_find_one, list_map_filter, list_join
+from pbu.default_options import default_options, default_value, list_find_one, list_map_filter, list_join, not_none
 from pbu.constant_listing import ConstantListing
 from pbu.performance_logger import PerformanceLogger
 from pbu.date_time import combine_date_time, to_utc, to_timezone, set_timezone, DATE_FORMAT, DATETIME_FORMAT
